Print method for twdtw class
# S3 method for twdtw
print(x, ...)This function returns a textual representation of the object twdtw, which is printed directly to the console.
If x is a list, the function will print a summary of matches and omit twdtw's internal data, see names(x).
If x is not a list, it prints the content of x, i.e. either a matrix with all matches or the lowest twdtw distance.
An object of class twdtw.
Arguments passed to print.default or other methods.